{% extends "Emailing/public/base_custom.html" %}
{% load i18n %}

{% block title %}{% trans "Unregister" %}{% endblock %}

{% block custom_content %}
  {% blocktrans %}<h1>Are you sure to unregister from our mailing-list?</h1>{% endblocktrans %}
  <form method="post" action="">{% csrf_token %}
    {{form.as_p}}
    <input type="submit" name="unregister" value="{% trans "Yes" %}">
    <input type="submit" name="cancel" value="{% trans "No" %}">
  </form>
{% endblock %}